@@ -406,12 +406,13 @@ GnomeFontFace *GPOFontMap::getFontFaceFallback(GfxFont *font)
 
 GnomeFontFace *GPOFontMap::getFontFace(GfxFont *font)
 {
+#ifdef HAVE_FONT_EMBEDDING
+  if (isEmbeddedFont(font))
+    return getFontFaceEmbedded(font);
+  else
+#endif
   if (isBase14Font(font))
     return getFontFaceBase14(font);
-#ifdef HAVE_FONT_EMBEDDING
-  else if (isEmbeddedFont(font))
-    return getFontFaceEmbedded(font);
-#endif
   else
     return getFontFaceFallback(font);
 }
